#!/usr/bin/env python

"""
Output context common functionality.

Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Output:

    "A common output context abstraction."

    default_encoding = "utf-8"

    def __init__(self, parameters=None):

        "Initialise the output context with the optional 'parameters'."

        self.parameters = parameters
        self.encoding = parameters and parameters.get("encoding") or self.default_encoding

        # Set up an output collector.

        self.output = []

    def encode(self, text):

        "Encode 'text' using the configured encoding."

        return encode(text, self.encoding)

    def out(self, text):

        "Add 'text' to the output collector."

        self.output.append(self.encode(text))

    def to_string(self):

        "Return the output as a plain string."

        return "".join(self.output)

def encode(s, encoding):

    "Encode 's' using 'encoding' if Unicode."

    if isinstance(s, unicode):
        return s.encode(encoding)
    else:
        return s

# vim: tabstop=4 expandtab shiftwidth=4
